==> centreon-web-24.04.18.tar.gz: centreon-web-24.04.18/www/front_src/src/Resources/translatedLabels.ts <==
export const labelAcknowledged = 'Acknowledged';
export const labelAcknowledge = 'Acknowledge';
export const labelAcknowledgedBy = 'Acknowledged by';
export const labelAcknowledgeServices = 'Acknowledge services attached to host';
export const labelAt = 'at';
export const labelActive = 'Active';
export const labelAdd = 'Add';
export const labelAll = 'All';
export const labelAuthor = 'Author';
export const labelComment = 'Comment';
export const labelCancel = 'Cancel';
export const labelClear = 'Clear';
export const labelCriterias = 'Criterias';
export const labelCritical = 'Critical';
export const labelCheckDuration = 'Check duration';
export const labelCommand = 'Command';
export const labelCopy = 'Copy';
export const labelCommandCopied = 'Command copied to clipboard';
export const labelCurrentNotificationNumber = 'Current notification number';
export const labelCurrentStatusDuration = 'Current status duration';
export const labelDetails = 'Details';
export const labelDown = 'Down';
export const labelDowntimeDuration = 'Downtime duration';
export const labelDuration = 'Duration';
export const labelSeconds = 'Seconds';
export const labelMinutes = 'Minutes';
export const labelHours = 'Hours';
export const labelEndTime = 'End time';
export const labelEntryTime = 'Entry time';
export const labelFilter = 'Filter';
export const labelNoDataForThisPeriod = 'No data available for this period';
export const labelResourceFlapping = 'This Resource is flapping';
export const labelFlapping = 'Flapping';
export const labelShowCriteriasFilters = 'Show criterias filters';
export const labelFrom = 'From';
export const labelStartDate = 'Start date';
export const labelEndDate = 'End date';
export const labelChangeStartDate = 'Change start date';
export const labelChangeStartTime = 'Change start time';
export const labelChangeEndDate = 'Change end date';
export const labelChangeEndTime = 'Change end time';
export const labelFixed = 'Fixed';
export const labelGraph = 'Graph';
export const labelHost = 'Host';
export const labelHostGroup = 'Host group';
export const labelDowntime = 'Downtime';
export const labelInDowntime = 'In downtime';
export const label1Day = '1 day';
export const label7Days = '7 days';
export const label31Days = '31 days';
export const labelLastDay = 'Last day';
export const labelLast7Days = 'Last 7 days';
export const labelLast31Days = 'Last 31 days';
export const labelSetDowntime = 'Set downtime';
export const labelSetDowntimeOn = 'Set downtime on';
export const labelDowntimeBy = 'Downtime set by';
export const labelSetDowntimeOnServices =
  'Set downtime on services attached to host';
export const labelCheck = 'Check';
export const labelLastCheck = 'Last check';
export const labelLastNotification = 'Last notification';
export const labelLastStatusChange = 'Last status change';
export const labelLatency = 'Latency';
export const labelLess = 'Less';
export const labelNextCheck = 'Next check';
export const labelNo = 'No';
export const labelNotify = 'Notify';
export const labelNotifyHelpCaption =
  'If checked, a notification is sent to the contacts linked to the object to warn that the incident on the resource has been acknowledged';
export const labelOk = 'Ok';
export const labelOpen = 'Open';
export const labelStatusChangePercentage = 'Status change percentage';
export const labelPerformanceData = 'Performance data';
export const labelPersistent = 'Persistent';
export const labelPending = 'Pending';
export const labelMonitoringServer = 'Monitoring server';
export const labelRequired = 'Required';
export const labelResourceName = 'Resource name';
export const labelAllAlerts = 'All alerts';
export const labelResource = 'Resource';
export const labelRowsPerPage = 'Rows per page';
export const labelOf = 'of';
export const labelSearch = 'Search';
export const labelSeverity = 'Severity';
export const labelStatus = 'Status';
export const labelSticky = 'Sticky';
export const labelTries = 'Tries';
export const labelInformation = 'Information';
export const labelMore = 'More';
export const labelRefresh = 'Refresh';
export const labelDisableAutorefresh = 'Disable autorefresh';
export const labelEnableAutorefresh = 'Enable autorefresh';
export const labelSearchHelp = 'Search help';
export const labelSearchOnFields =
  'This search bar will search matching occurences you type, contained in: host name or alias or address or service description';
export const labelSearchByRegexp =
  'You can use regular expression syntax to retrieve more relevant results';
export const labelSearchSyntax =
  "It's possible to specify the criteria you precisely want to search, by using the following syntax:";
export const labelSearchSomeExamples = 'Some examples:';
export const labelSearchByHostNameStartingWith =
  'will display resources with host name starting by';
export const labelSearchByServiceDescEndingWith =
  'will display resources with service description finishing by';
export const labelSearchByHostAliasContaining =
  'will display all resources with host having alias containing';
export const labelSearchByHostAddressNotContaining =
  "will display resources having FQDN that doesn't contain";
export const labelSearchAndHostAliasContaining = 'and host alias containing';
export const labelTips = 'Tips';
export const labelGetRegexHelp =
  'get some help while creating your regular expression query at';
export const labelService = 'Service';
export const labelServices = 'Services';
export const labelServiceGroup = 'Service group';
export const labelStartTime = 'Start time';
export const labelState = 'State';
export const labelStateFilter = 'State filter';
export const labelStatusInformation = 'Status information';
export const labelTimezone = 'Timezone';
export const labelTo = 'To';
export const labelAcknowledgeCommandSent = 'Acknowledge command sent';
export const labelDowntimeCommandSent = 'Downtime command sent';
export const labelCheckCommandSent =
  'Check command sent ! Please refresh the listing to update the data.';
export const labelTypeOfResource = 'Type of resource';
export const labelUnhandledAlerts = 'Unhandled alerts';
export const labelUnhandled = 'Unhandled';
export const labelUnreachable = 'Unreachable';
export const labelUnknown = 'Unknown';
export const labelUp = 'Up';
export const labelYes = 'Yes';
export const labelSomethingWentWrong = 'Oops, something went wrong';
export const labelWarning = 'Warning';
export const labelApiNotFoundNotUpToDate =
  'Seems that your Apache configuration is not up-to-date';
export const labelApiNotFoundContactAdmin =
  'Contact your Centreon administrator or update the following file';
export const labelApiNotFoundDocumentation = 'See Documentation';
export const labelServicesDenied =
  "Services will not be affected because you don't have sufficient permission";
export const labelHostsDenied =
  "Hosts will not be affected because you don't have sufficient permission";
export const labelNoResultsFound = 'No results found';
export const labelSaveFilter = 'Save filter';
export const labelSaveAsNew = 'Save as new';
export const labelSave = 'Save';
export const labelNewFilter = 'New filter';
export const labelUpdateFilter = 'Update filter';
export const labelName = 'Name';
export const labelFilterCreated = 'Filter created';
export const labelFilterSaved = 'Filter saved';
export const labelMyFilters = 'My filters';
export const labelManageFilters = 'Manage filters';
export const labelRename = 'Rename';
export const labelDelete = 'Delete';
export const labelAskDelete = 'Delete filter?';
export const labelFilterDeleted = 'Filter deleted';
export const labelFilterUpdated = 'Filter updated';
export const labelNameCannotBeEmpty = 'Name cannot be empty';
export const labelTimeline = 'Timeline';
export const labelEvent = 'Event';
export const labelAcknowledgement = 'Acknowledgement';
export const labelBy = 'by';
export const labelNotificationSentTo = 'Notification sent to';
export const labelNotification = 'Notification';
export const labelShortcuts = 'Shortcuts';
export const labelConfigure = 'Configure';
export const labelViewLogs = 'View logs';
export const labelViewReport = 'View report';
export const labelCopyLink = 'Copy the link to this resource';
export const labelLinkCopied = 'Resource link copied to the clipboard';
export const labelDisacknowledge = 'Disacknowledge';
export const labelMoreActions = 'More actions';
export const labelDisacknowledgeServices =
  'Disacknowledge services attached to hosts';
export const labelDisacknowledgementCommandSent =
  'Disacknowledgement command sent';
export const labelSubmitStatus = 'Submit a status';
export const labelSubmit = 'Submit';
export const labelStatusSubmitted = 'Status submitted';
export const labelOutput = 'Output';
export const labelNoResourceFound = 'No resource found';
export const labelFqdn = 'FQDN / Address';
export const labelAlias = 'Alias';
export const labelUrl = 'URL';
export const labelSwitchToGraph = 'Switch to graph mode';
export const labelSwitchToList = 'Switch to list mode';
export const labelNoDataFor = 'No data for';
export const labelGroups = 'Groups';
export const labelAddComment = 'Add a comment';
export const labelCommentAdded = 'Comment added';
export const labelDisplayEvents = 'Display events';
export const labelExportToPng = 'Export to png';
export const labelPerformancePage = 'Go to performance page';
export const labelParent = 'Parent';
export const labelParentName = 'Parent name';
export const labelSelectCriterias = 'Select criterias';
export const labelForward = 'Forward';
export const labelBackward = 'Backward';
export const labelEndDateGreaterThanStartDate =
  'The end date must be greater than the start date';
export const labelGraphOptions = 'Graph options';
export const labelMin = 'Min';
export const labelMax = 'Max';
export const labelAvg = 'Avg';
export const labelCompactTimePeriod = 'Compact time period';
export const labelAction = 'Action';
export const labelNotes = 'Notes';
export const labelChecksDisabled = 'All checks are disabled';
export const labelOnlyPassiveChecksEnabled = 'Only passive checks are enabled';
export const labelNotificationDisabled = 'Notifications disabled';
export const labelNotificationEnabled = 'Notifications enabled';
export const labelMetrics = 'Metrics';
export const labelMetaService = 'Meta-Service';
export const labelCalculationType = 'Calculation type';
export const labelSelectAtLeastOneColumn =
  'At least one column must be selected';
export const labelMaxDuration1Year = 'The duration must be less than a year';
export const labelSearchOptions = 'Filter options';
export const labelDisplayCompleteGraph = 'Display the complete graph';
export const labelActionNotPermitted = 'Action not permitted';
export const labelScrollToTop = 'Scroll to top';
export const labelToday = 'Today';
export const labelYesterday = 'Yesterday';
export const labelThisWeek = 'This week';
export const labelLastWeek = 'Last week';
export const labelLastMonth = 'Last month';
export const labelLastYear = 'Last year';
export const labelBeforeLastYear = 'Before last year';
export const labelServiceGraphs = 'Service graphs';
export const labelClearFilter = 'Clear filter';
export const labelLastCheckWithOkStatus = 'Last check with OK status';
export const labelStatusType = 'Status type';
export const labelHard = 'Hard';
export const labelSoft = 'Soft';
export const labelInvalidFormat = 'Invalid format';
export const labelType = 'Type';
export const labelEmail = 'E-mail';
export const labelContacts = 'Contacts';
export const labelContactGroups = 'Contact groups';
export const labelSettings = 'Settings';
export const labelNotificationStatus = 'Notification status';
export const labelConfiguration = 'Configuration';
export const labelNotAuthorizedToAccessConfiguration =
  'You are not authorized to access the configuration';
export const labelForceActiveChecks = 'Force active checks';
export const labelNoContactIsConfiguredForThisResource =
  'No contacts are configured for this resource';
export const labelNoContactGroupsIsConfiguredForThisResource =
  'No contact groups are configured for this resource';
export const labelParentAlias = 'Parent alias';
export const labelCategories = 'Categories';
export const labelHostCategory = 'Host category';
export const labelServiceCategory = 'Service category';
export const labelExportToCSV = 'Export to CSV';
export const labelServiceSeverity = 'Service severity';
export const labelHostSeverity = 'Host severity';
export const labelHostSeverityLevel = 'Host severity level';
export const labelServiceSeverityLevel = 'Service severity level';
export const labelCSV = 'CSV';
export const labelExport = 'Export';
export const labelExportAs = 'Export as';
export const labelPNGAsDisplayed = 'PNG (as displayed)';
export const labelPNGMediumSize = 'PNG (medium size)';
export const labelPNGSmallSize = 'PNG (small size)';
export const labelEditAnomalyDetectionData = 'Edit anomaly detection data';
export const labelAnomalyDetection = 'Anomaly detection';
export const labelPerformanceGraphAD = 'Edit anomaly detection data';
export const labelEditAnomalyDetectionConfirmation =
  'Are you sure you want to change the size of the envelope? The new envelope size will be applied immediately.';
export const labelMenageEnvelope = 'Manage envelope size';
export const labelMenageEnvelopeSubTitle =
  'Changes to the envelope size will be applied immediately';
export const labelResetToDefaultValue = 'Reset to default value';
export const labelPointsOutsideOfEnvelopeCount =
  'points outside of the envelope';
export const labelClose = 'Close';
export const labelSearchBar = 'Search bar';
export const labelSlider = 'Slider';
export const labelCloseEditModal = 'Close edit modal';
export const labelModalEditAnomalyDetection = 'Edit modal';
export const labelModalConfirmation = 'Modal confirmation';
export const labelForcedCheck = 'Forced check';
export const labelCheckDescription = `Check selected resources only within configured check period`;
export const labelForcedCheckDescription =
  'Check selected resources even outside configured check period';
export const labelForcedCheckCommandSent =
  'Forced check command sent ! Please refresh the listing to update the data.';
export const labelUnit = 'Unit';
export const labelNeedHelpWithSearchBarUsage =
  'Need help using the search bar ?';
export const labelFindExplanationsAndExamples =
  'Find explanations and examples';
export const labelHere = 'here';

export const labelDisplayView = 'Display view:';
export const labelViewAllResources = 'View all resources';
export const labelViewByHost = 'View by host';
export const labelViewByService = 'View by service';
export const labelResourceDetailsForcedCheckCommandSent =
  'Forced check command sent !';
export const labelResourceDetailsCheckCommandSent = 'Check command sent !';

export const labelResourceDetailsCheckDescription =
  'Check this resource only within configured check period';
export const labelResourceDetailsForcedCheckDescription =
  'Check this resource even outside configured check period';

export const labelYourCommentSent = 'Your comment has been saved.';

export const labelCompact = 'Compact';
export const labelExtended = 'Extended';

export const labelFreeTextSearchBehavior =
  'Free text search behavior can be configured in the Administration > Parameters > Centreon UI page.';

==> centreon-web-24.10.13.tar.gz: centreon-web-24.10.13/www/front_src/src/Resources/translatedLabels.ts <==
export const labelAcknowledged = 'Acknowledged';
export const labelAcknowledge = 'Acknowledge';
export const labelAcknowledgedBy = 'Acknowledged by';
export const labelAcknowledgeServices = 'Acknowledge services attached to host';
export const labelAt = 'at';
export const labelActive = 'Active';
export const labelAdd = 'Add';
export const labelAll = 'All';
export const labelAuthor = 'Author';
export const labelComment = 'Comment';
export const labelCancel = 'Cancel';
export const labelClear = 'Clear';
export const labelCriterias = 'Criterias';
export const labelCritical = 'Critical';
export const labelCheckDuration = 'Check duration';
export const labelCommand = 'Command';
export const labelCopy = 'Copy';
export const labelCommandCopied = 'Command copied to clipboard';
export const labelCurrentNotificationNumber = 'Current notification number';
export const labelCurrentStatusDuration = 'Current status duration';
export const labelDetails = 'Details';
export const labelDown = 'Down';
export const labelDowntimeDuration = 'Downtime duration';
export const labelDuration = 'Duration';
export const labelSeconds = 'Seconds';
export const labelMinutes = 'Minutes';
export const labelHours = 'Hours';
export const labelEndTime = 'End time';
export const labelEntryTime = 'Entry time';
export const labelFilter = 'Filter';
export const labelNoDataForThisPeriod = 'No data available for this period';
export const labelResourceFlapping = 'This resource is flapping';
export const labelFlapping = 'Flapping';
export const labelShowCriteriasFilters = 'Show criterias filters';
export const labelFrom = 'From';
export const labelStartDate = 'Start date';
export const labelEndDate = 'End date';
export const labelChangeStartDate = 'Change start date';
export const labelChangeStartTime = 'Change start time';
export const labelChangeEndDate = 'Change end date';
export const labelChangeEndTime = 'Change end time';
export const labelFixed = 'Fixed';
export const labelGraph = 'Graph';
export const labelHost = 'Host';
export const labelHostGroup = 'Host group';
export const labelDowntime = 'Downtime';
export const labelInDowntime = 'In downtime';
export const label1Day = '1 day';
export const label7Days = '7 days';
export const label31Days = '31 days';
export const labelLastDay = 'Last day';
export const labelLast7Days = 'Last 7 days';
export const labelLast31Days = 'Last 31 days';
export const labelSetDowntime = 'Set downtime';
export const labelSetDowntimeOn = 'Set downtime on';
export const labelDowntimeBy = 'Downtime set by';
export const labelSetDowntimeOnServices =
  'Set downtime on services attached to host';
export const labelCheck = 'Check';
export const labelLastCheck = 'Last check';
export const labelLastNotification = 'Last notification';
export const labelLastStatusChange = 'Last status change';
export const labelLatency = 'Latency';
export const labelLess = 'Less';
export const labelNextCheck = 'Next check';
export const labelNo = 'No';
export const labelNotify = 'Notify';
export const labelNotifyHelpCaption =
  'If checked, a notification is sent to the contacts linked to the object to warn that the incident on the resource has been acknowledged';
export const labelOk = 'Ok';
export const labelOpen = 'Open';
export const labelStatusChangePercentage = 'Status change percentage';
export const labelPerformanceData = 'Performance data';
export const labelPersistent = 'Persistent';
export const labelPending = 'Pending';
export const labelMonitoringServer = 'Monitoring server';
export const labelRequired = 'Required';
export const labelResourceName = 'Resource name';
export const labelAllAlerts = 'All alerts';
export const labelResource = 'Resource';
export const labelRowsPerPage = 'Rows per page';
export const labelOf = 'of';
export const labelSearch = 'Search';
export const labelSeverity = 'Severity';
export const labelStatus = 'Status';
export const labelSticky = 'Sticky';
export const labelTries = 'Tries';
export const labelInformation = 'Information';
export const labelMore = 'More';
export const labelRefresh = 'Refresh';
export const labelDisableAutorefresh = 'Disable autorefresh';
export const labelEnableAutorefresh = 'Enable autorefresh';
export const labelSearchHelp = 'Search help';
export const labelSearchOnFields =
  'This search bar will search matching occurences you type, contained in: host name or alias or address or service description';
export const labelSearchByRegexp =
  'You can use regular expression syntax to retrieve more relevant results';
export const labelSearchSyntax =
  "It's possible to specify the criteria you precisely want to search, by using the following syntax:";
export const labelSearchSomeExamples = 'Some examples:';
export const labelSearchByHostNameStartingWith =
  'will display resources with host name starting by';
export const labelSearchByServiceDescEndingWith =
  'will display resources with service description finishing by';
export const labelSearchByHostAliasContaining =
  'will display all resources with host having alias containing';
export const labelSearchByHostAddressNotContaining =
  "will display resources having FQDN that doesn't contain";
export const labelSearchAndHostAliasContaining = 'and host alias containing';
export const labelTips = 'Tips';
export const labelGetRegexHelp =
  'get some help while creating your regular expression query at';
export const labelService = 'Service';
export const labelServices = 'Services';
export const labelServiceGroup = 'Service group';
export const labelStartTime = 'Start time';
export const labelState = 'State';
export const labelStateFilter = 'State filter';
export const labelStatusInformation = 'Status information';
export const labelTimezone = 'Timezone';
export const labelTo = 'To';
export const labelAcknowledgeCommandSent = 'Acknowledge command sent';
export const labelDowntimeCommandSent = 'Downtime command sent';
export const labelCheckCommandSent =
  'Check command sent ! Please refresh the listing to update the data.';
export const labelTypeOfResource = 'Type of resource';
export const labelUnhandledAlerts = 'Unhandled alerts';
export const labelUnhandled = 'Unhandled';
export const labelUnreachable = 'Unreachable';
export const labelUnknown = 'Unknown';
export const labelUp = 'Up';
export const labelYes = 'Yes';
export const labelSomethingWentWrong = 'Oops, something went wrong';
export const labelWarning = 'Warning';
export const labelApiNotFoundNotUpToDate =
  'Seems that your Apache configuration is not up-to-date';
export const labelApiNotFoundContactAdmin =
  'Contact your Centreon administrator or update the following file';
export const labelApiNotFoundDocumentation = 'See Documentation';
export const labelServicesDenied =
  "Services will not be affected because you don't have sufficient permission";
export const labelHostsDenied =
  "Hosts will not be affected because you don't have sufficient permission";
export const labelNoResultsFound = 'No results found';
export const labelSaveFilter = 'Save filter';
export const labelSaveAsNew = 'Save as new';
export const labelSave = 'Save';
export const labelNewFilter = 'New filter';
export const labelUpdateFilter = 'Update filter';
export const labelName = 'Name';
export const labelFilterCreated = 'Filter created';
export const labelFilterSaved = 'Filter saved';
export const labelMyFilters = 'My filters';
export const labelManageFilters = 'Manage filters';
export const labelRename = 'Rename';
export const labelDelete = 'Delete';
export const labelAskDelete = 'Delete filter?';
export const labelFilterDeleted = 'Filter deleted';
export const labelFilterUpdated = 'Filter updated';
export const labelNameCannotBeEmpty = 'Name cannot be empty';
export const labelTimeline = 'Timeline';
export const labelEvent = 'Event';
export const labelAcknowledgement = 'Acknowledgement';
export const labelBy = 'by';
export const labelNotificationSentTo = 'Notification sent to';
export const labelNotification = 'Notification';
export const labelShortcuts = 'Shortcuts';
export const labelConfigure = 'Configure';
export const labelViewLogs = 'View logs';
export const labelViewReport = 'View report';
export const labelCopyLink = 'Copy the link to this resource';
export const labelLinkCopied = 'Resource link copied to the clipboard';
export const labelDisacknowledge = 'Disacknowledge';
export const labelMoreActions = 'More actions';
export const labelDisacknowledgeServices =
  'Disacknowledge services attached to hosts';
export const labelDisacknowledgementCommandSent =
  'Disacknowledgement command sent';
export const labelSubmitStatus = 'Submit a status';
export const labelSubmit = 'Submit';
export const labelStatusSubmitted = 'Status submitted';
export const labelOutput = 'Output';
export const labelNoResourceFound = 'No resource found';
export const labelFqdn = 'FQDN / Address';
export const labelAlias = 'Alias';
export const labelUrl = 'URL';
export const labelSwitchToGraph = 'Switch to graph mode';
export const labelSwitchToList = 'Switch to list mode';
export const labelNoDataFor = 'No data for';
export const labelGroups = 'Groups';
export const labelAddComment = 'Add a comment';
export const labelCommentAdded = 'Comment added';
export const labelDisplayEvents = 'Display events';
export const labelExportToPng = 'Export to png';
export const labelPerformancePage = 'Go to performance page';
export const labelParent = 'Parent';
export const labelParentName = 'Parent name';
export const labelSelectCriterias = 'Select criterias';
export const labelForward = 'Forward';
export const labelBackward = 'Backward';
export const labelEndDateGreaterThanStartDate =
  'The end date must be greater than the start date';
export const labelGraphOptions = 'Graph options';
export const labelMin = 'Min';
export const labelMax = 'Max';
export const labelAvg = 'Avg';
export const labelCompactTimePeriod = 'Compact time period';
export const labelAction = 'Action';
export const labelNotes = 'Notes';
export const labelChecksDisabled = 'All checks are disabled';
export const labelOnlyPassiveChecksEnabled = 'Only passive checks are enabled';
export const labelNotificationDisabled = 'Notifications disabled';
export const labelNotificationEnabled = 'Notifications enabled';
export const labelMetrics = 'Metrics';
export const labelMetaService = 'Meta-Service';
export const labelCalculationType = 'Calculation type';
export const labelSelectAtLeastOneColumn =
  'At least one column must be selected';
export const labelMaxDuration1Year = 'The duration must be less than a year';
export const labelSearchOptions = 'Filter options';
export const labelDisplayCompleteGraph = 'Display the complete graph';
export const labelActionNotPermitted = 'Action not permitted';
export const labelScrollToTop = 'Scroll to top';
export const labelToday = 'Today';
export const labelYesterday = 'Yesterday';
export const labelThisWeek = 'This week';
export const labelLastWeek = 'Last week';
export const labelLastMonth = 'Last month';
export const labelLastYear = 'Last year';
export const labelBeforeLastYear = 'Before last year';
export const labelServiceGraphs = 'Service graphs';
export const labelClearFilter = 'Clear filter';
export const labelLastCheckWithOkStatus = 'Last check with OK status';
export const labelStatusType = 'Status type';
export const labelHard = 'Hard';
export const labelSoft = 'Soft';
export const labelInvalidFormat = 'Invalid format';
export const labelType = 'Type';
export const labelEmail = 'E-mail';
export const labelContacts = 'Contacts';
export const labelContactGroups = 'Contact groups';
export const labelSettings = 'Settings';
export const labelNotificationStatus = 'Notification status';
export const labelConfiguration = 'Configuration';
export const labelNotAuthorizedToAccessConfiguration =
  'You are not authorized to access the configuration';
export const labelForceActiveChecks = 'Force active checks';
export const labelNoContactIsConfiguredForThisResource =
  'No contacts are configured for this resource';
export const labelNoContactGroupsIsConfiguredForThisResource =
  'No contact groups are configured for this resource';
export const labelParentAlias = 'Parent alias';
export const labelCategories = 'Categories';
export const labelHostCategory = 'Host category';
export const labelServiceCategory = 'Service category';
export const labelExportToCSV = 'Export to CSV';
export const labelServiceSeverity = 'Service severity';
export const labelHostSeverity = 'Host severity';
export const labelHostSeverityLevel = 'Host severity level';
export const labelServiceSeverityLevel = 'Service severity level';
export const labelCSV = 'CSV';
export const labelExport = 'Export';
export const labelExportAs = 'Export as';
export const labelPNGAsDisplayed = 'PNG (as displayed)';
export const labelPNGMediumSize = 'PNG (medium size)';
export const labelPNGSmallSize = 'PNG (small size)';
export const labelEditAnomalyDetectionData = 'Edit anomaly detection data';
export const labelAnomalyDetection = 'Anomaly detection';
export const labelPerformanceGraphAD = 'Edit anomaly detection data';
export const labelEditAnomalyDetectionConfirmation =
  'Are you sure you want to change the size of the envelope? The new envelope size will be applied immediately.';
export const labelMenageEnvelope = 'Manage envelope size';
export const labelMenageEnvelopeSubTitle =
  'Changes to the envelope size will be applied immediately';
export const labelResetToDefaultValue = 'Reset to default value';
export const labelPointsOutsideOfEnvelopeCount =
  'points outside of the envelope';
export const labelClose = 'Close';
export const labelSearchBar = 'Search bar';
export const labelSlider = 'Slider';
export const labelCloseEditModal = 'Close edit modal';
export const labelModalEditAnomalyDetection = 'Edit modal';
export const labelModalConfirmation = 'Modal confirmation';
export const labelForcedCheck = 'Forced check';
export const labelCheckDescription =
  'Check selected resources only within configured check period';
export const labelForcedCheckDescription =
  'Check selected resources even outside configured check period';
export const labelForcedCheckCommandSent =
  'Forced check command sent ! Please refresh the listing to update the data.';
export const labelUnit = 'Unit';
export const labelNeedHelpWithSearchBarUsage =
  'Need help using the search bar ?';
export const labelFindExplanationsAndExamples =
  'Find explanations and examples';
export const labelHere = 'here';

export const labelDisplayView = 'Display view:';
export const labelViewAllResources = 'View all resources';
export const labelViewByHost = 'View by host';
export const labelViewByService = 'View by service';
export const labelResourceDetailsForcedCheckCommandSent =
  'Forced check command sent !';
export const labelResourceDetailsCheckCommandSent = 'Check command sent !';

export const labelResourceDetailsCheckDescription =
  'Check this resource only within configured check period';
export const labelResourceDetailsForcedCheckDescription =
  'Check this resource even outside configured check period';

export const labelYourCommentSent = 'Your comment has been saved.';

export const labelVisibleColumnsOnly = 'Visible columns only';
export const labelAllColumns = 'All columns';
export const labelAllPages = 'All pages';
export const labelCurrentPageOnly = 'Current page only';
export const labelSelectColumns = 'Select columns';
export const labelSelecetPages = 'Select pages';
export const labelNumerOfLines = 'Number of rows';
export const labelWarningExportToCsv =
  'Export processing might take some time. The real time data displayed at the output may have changed since the start of processing.';
export const labelExportProcessingInProgress = 'Export processing in progress';
export const labelFilteredResources =
  'You are about to export the status of the resources you have filtered. You can export up to 10,000 rows.';
export const labelFilterRessources =
  'Export will be processed but will not include all rows. You can still filter your resources to reduce the number of rows.';

export const labelCompact = 'Compact';
export const labelExtended = 'Extended';

export const labelFreeTextSearchBehavior =
  'Free text search behavior can be configured in the Administration > Parameters > Centreon UI page.';
